@@ -269,9 +269,9 @@ class ImageRecognition(object):
                         x_batch.append(tmp_x)
                         y_pred.append(tmp_y)
 
-                        flip_tmp_x = np.flip(tmp_x, 0)
-                        x_batch.append(flip_tmp_x)
-                        y_pred.append(tmp_y)
+                        #flip_tmp_x = np.flip(tmp_x, 0)
+                        #x_batch.append(flip_tmp_x)
+                        #y_pred.append(tmp_y)
 
                         flip_tmp_x = np.flip(tmp_x, 1)
                         x_batch.append(flip_tmp_x)
@@ -280,6 +280,7 @@ class ImageRecognition(object):
                         if rand_num == 1: 
                             gray_tmp_x = cv2.imread(dataset_path + i + "/" + file_list_by_class[i][idx[i]])
                             gray_tmp_x = cv2.cvtColor(gray_tmp_x, cv2.COLOR_BGR2GRAY)
+                            gray_tmp_x = cv2.cvtColor(gray_tmp_x, cv2.COLOR_GRAY2RGB)
                             gray_tmp_x = cv2.resize(gray_tmp_x, dsize=(self.input_width, self.input_height), interpolation=cv2.INTER_CUBIC)
                             gray_tmp_x = gray_tmp_x.astype(np.float32) / 255.
                             x_batch.append(gray_tmp_x)
